// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef MAILTRANSPORT_VERSION_H
#define MAILTRANSPORT_VERSION_H

#define MAILTRANSPORT_VERSION_STRING "6.7.3"
#define MAILTRANSPORT_VERSION_MAJOR 6
#define MAILTRANSPORT_VERSION_MINOR 7
#define MAILTRANSPORT_VERSION_PATCH 3
#define MAILTRANSPORT_VERSION ((6<<16)|(7<<8)|(3))

#endif
